.. currentmodule:: cf_units

Date and Time Utility Functions
===============================

A number of utility functions for encoding and decoding date and time units supplied with cf_units.
These are documented below.

.. autofunction:: encode_time
.. autofunction:: encode_date
.. autofunction:: encode_clock
.. autofunction:: decode_time

.. autofunction:: date2num
.. autofunction:: num2date
.. autofunction:: num2pydate

.. autodata:: CALENDARS
.. autodata:: CALENDAR_ALIASES
